import 'package:yuro_cli/core/core.dart';

abstract class YamlUtil {
  static bool checkYamlFile() {
    if (!File(join(PROJECT_PATH!, 'pubspec.yaml')).existsSync()) {
      logger.e('\nUnable to find pubspec.yaml in the path of "${PROJECT_PATH!}"');
      return false;
    }
    return true;
  }

  /// 获取CLI的本地版本,需要先配置[PUB_HOME]或[FLUTTER_PUB_HOME]
  static Future<String?> getNativeVersion() async {
    var pubPath = PUB_PATH ?? FLUTTER_PUB_PATH;
    if (pubPath != null) {
      var lockFile = File(join(pubPath, 'global_packages/yuro_cli/pubspec.lock'));
      if (lockFile.existsSync()) {
        var yamlMap = loadYaml(lockFile.readAsStringSync()) as YamlMap;
        return yamlMap['packages']['yuro_cli']['version'].toString();
      } else {
        logger.e('Yuo can use command "pub global activate yuro_cli" or "flutter pub global activate yuro_cli" to get this cli.');
        return null;
      }
    } else {
      logger.e('Unable to find PUB_HOME or FLUTTER_PUB_HOME in environment variables, you must configure it first.');
      return null;
    }
  }

  /// 注册资源目录到pubspec.yaml文件中
  static void registerAssets(String path) {
    if (PROJECT_PATH != null) {
      var yamlFile = File(join(PROJECT_PATH!, 'pubspec.yaml'));
      var yamlMap = loadYaml(yamlFile.readAsStringSync()) as YamlMap;
      if (!yamlMap.containsKey('flutter')) {
        yamlFile.writeAsStringSync('\n\rflutter:', mode: FileMode.append, flush: true);
        yamlMap = loadYaml(yamlFile.readAsStringSync()) as YamlMap;
      }
      var flutter = yamlMap['flutter'] as YamlMap?;
      if (flutter == null || !flutter.containsKey('assets')) {
        yamlFile.writeAsStringSync('\r  assets:', mode: FileMode.append, flush: true);
        yamlMap = loadYaml(yamlFile.readAsStringSync()) as YamlMap;
      }
      var assets = flutter?['assets'] as YamlList?;
      if (assets == null || !assets.contains(path)) {
        yamlFile.writeAsStringSync('\r    - $path', mode: FileMode.append, flush: true);
      }
    } else {
      logger.w(
          'PROJECT_PATH was not found, the resource failed to be registered successfully, please add it manually in the pubspec.yaml file.');
    }
  }

  /// 执行"flutter pub get"命令
  static void runFlutterPubGet() async {
    var res = await runExecutableArguments('flutter', ['pub', 'get'], verbose: true);
    if (res.exitCode != 0) {
      logger.e('\nError: ${res.stderr}');
      logger.e('Process finished with exit code ${res.exitCode}.\n');
    } else {
      logger.i('Process finished with exit code ${res.exitCode}.\n');
    }
  }
}
